summary refs log tree commit diff
path: root/curtis/.config/nvim
diff options
context:
space:
mode:
authorJune McEnroe <june@causal.agency>2022-10-17 17:22:39 -0400
committerJune McEnroe <june@causal.agency>2022-10-17 17:22:39 -0400
commitb4459e8cbbf18f95c42bdbdf33baeef689d76415 (patch)
treea61f895b9faa046af15cb66f8e43edf616f6809c /curtis/.config/nvim
parentFix same month, different day diffs (diff)
downloadsrc-b4459e8cbbf18f95c42bdbdf33baeef689d76415.tar.gz
src-b4459e8cbbf18f95c42bdbdf33baeef689d76415.zip
Fix 3- and 4-byte UTF-8 sequence matching
lex(1) has weird regex precedence rules!
Diffstat (limited to 'curtis/.config/nvim')
0 files changed, 0 insertions, 0 deletions
er-highlight'> I hate these things and also this one sucks. 2021-09-21Use Z_FILTERED strategyJune McEnroe 2021-09-21Recalculate various lengths only as neededJune McEnroe This actually speeds things up quite a bit, saving roughly a second on a big PNG screenshot. Almost all the remaining time is spent in deflate. 2021-09-21Rewrite pngo, add explicit optionsJune McEnroe Interesting to see how my code habits have changed. 2021-09-16Fix /* **/ comment matchingJune McEnroe 2021-09-15Remove typer, add downgrade to READMEJune McEnroe 2021-09-15Set bot mode on downgradeJune McEnroe 2021-09-15Enter capsicum in downgradeJune McEnroe 2021-09-15Factor out common parts of downgrade messagesJune McEnroe Also bump the message cap to 1024 because that is ostensibly useful for replying to older messages. 2021-09-14Add downgrade IRC botJune McEnroe 2021-09-14Sort by title if authors matchJune McEnroe There are probably better things to sort by but title definitely always exists. 2021-09-13Swap-remove tags as they're foundJune McEnroe This makes it even faster. From ~1s on a sqlite3.c amalgamation to ~0.85s. 2021-09-12Replace htagml regex with strncmpJune McEnroe Since ctags only ever produces regular expressions of the form /^re$/ or /^re/ with no other special characters, instead unescape the pattern and simply use strncmp. Running on a sqlite3.c amalgamation, the regex version takes ~37s while the strncmp version takes ~1s, producing identical output. Big win! 2021-09-11Also defer printing comment for lone close-parensJune McEnroe 2021-09-10Publish "git-comment"June McEnroe 2021-09-10Add git comment --pretty optionJune McEnroe 2021-09-08Defer printing comment if line is blank or closing braceJune McEnroe This fixes badly indented comments. 2021-09-08Up default min-repeat to 30 linesJune McEnroe 2021-09-08Handle dirty lines in git-commentJune McEnroe 2021-09-08Document and install git-commentJune McEnroe 2021-09-08Add repeat and all options to git-commentJune McEnroe 2021-09-08Add group threshold to git-commentJune McEnroe